## What's Changed

hotfix of v4.12.0

fix: 修复会话隔离功能失效的问题。

### 新增

- AstrBot 代理沙箱环境（改进的代码解释器） ([#4449](https://github.com/AstrBotDevs/AstrBot/issues/4449))，详见[文档](https://docs.astrbot.app/use/astrbot-agent-sandbox.html)
- ChatUI 支持项目管理 ([#4477](https://github.com/AstrBotDevs/AstrBot/issues/4477))
- 自定义规则支持批量处理。

### 修复

- 发送 OpenAI 风格的 image_url 导致 Anthropic 返回 400 无效标签错误 ([#4444](https://github.com/AstrBotDevs/AstrBot/issues/4444))
- ChatUI 标题显示问题 ([#4486](https://github.com/AstrBotDevs/AstrBot/issues/4486))
- 确保 ChatUI 消息流顺序正确 ([#4487](https://github.com/AstrBotDevs/AstrBot/issues/4487))
- 从 Telegram 和 Discord 平台命令注册中排除已禁用的命令 ([#4485](https://github.com/AstrBotDevs/AstrBot/issues/4485))

### 优化

- 优化工具调用相关的提示词
- 标准化 Context 类文档格式 ([#4436](https://github.com/AstrBotDevs/AstrBot/issues/4436))
